@@ -18,18 +18,20 @@ def login(server_url: str, key: str = None, key_file: str = None) -> SemanthaAPI
     Returns:
         SemanthaAPI: Entry point to the Semantha API.
     """
+    if(not server_url.endswith("/tt-platform-server")):
+        server_url += "/tt-platform-server"
     __s = None
     if key:
-        __s = SemanthaAPI(RestClient(server_url, key), f"/api/{__PLATFORM_SERVER_API_VERSION}")
+        pass
     elif key_file:
         with open(key_file, "r") as key_file:
-            __s = SemanthaAPI(RestClient(server_url, json.load(key_file)['API_Key']),
-                              f"/api/{__PLATFORM_SERVER_API_VERSION}"
-                              )
+            key = json.load(key_file)['API_Key']
     else:
         raise ValueError("You need to supply an API key to login, either directly or via a file.")
+    
+    __s = SemanthaAPI(RestClient(server_url, key), f"/api/{__PLATFORM_SERVER_API_VERSION}", "/api")
 
     # check whether API key is valid or not
-    __s.current_user.get()
+    __s.currentuser.get()
 
     return __s
