@@ -1,12 +1,11 @@
 from __future__ import annotations
 
 from semantha_sdk.api.semantha_endpoint import SemanthaAPIEndpoint
-from semantha_sdk.model.schema.user_data import UserDataSchema
-from semantha_sdk.model.user_data import UserData
+from semantha_sdk.model.user_data import UserData, UserDataSchema
 from semantha_sdk.rest.rest_client import RestClient
 
 
-class CurrentUserRoles(SemanthaAPIEndpoint):
+class CurrentUserRolesEndpoint(SemanthaAPIEndpoint):
     """ Access role(s) information about the currently logged-in user. """
 
     @property
@@ -17,12 +16,12 @@ class CurrentUserRoles(SemanthaAPIEndpoint):
         return self._session.get(self._endpoint).execute().as_list()
 
 
-class CurrentUser(SemanthaAPIEndpoint):
+class CurrentUserEndpoint(SemanthaAPIEndpoint):
     """ Access information about the currently logged-in user. """
 
     def __init__(self, session: RestClient, parent_endpoint: str):
         super().__init__(session, parent_endpoint)
-        self.__roles = CurrentUserRoles(session, self._endpoint)
+        self.__roles = CurrentUserRolesEndpoint(session, self._endpoint)
 
     @property
     def _endpoint(self):
