@@ -1,7 +1,7 @@
 from semantha_sdk.api.semantha_endpoint import SemanthaAPIEndpoint
 
 
-class MetadataTypes(SemanthaAPIEndpoint):
+class MetadataTypesEndpoint(SemanthaAPIEndpoint):
     """ api/model/metadatatypes endpoint. """
 
     @property
