@@ -4,6 +4,7 @@ from semantha_sdk.api.metadata_types import MetadataTypesEndpoint
 from semantha_sdk.api.semantha_endpoint import SemanthaAPIEndpoint
 from semantha_sdk.rest.rest_client import RestClient
 
+from typing import List
 
 class ModelEndpoint(SemanthaAPIEndpoint):
     """
@@ -27,12 +28,16 @@ class ModelEndpoint(SemanthaAPIEndpoint):
         return self.__model_domains
 
     @property
-    def extractor_types(self):
+    def extractortypes(self):
         return self.__extractor_types
 
     @property
-    def metadata_types(self):
+    def metadatatypes(self):
         return self.__metadata_types
 
+    def datatypes(self) -> List[str]:
+        endpoint = f"{self._endpoint}/datatypes"
+        return self._session.get(endpoint).execute().as_list()
+
     def __call__(self, domain: str) -> DomainModelEndpoint:
         return DomainModelEndpoint(self._session, self._endpoint, domain)
