@@ -1,13 +1,14 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from typing import List
 
-from marshmallow import Schema, fields, post_load
+from marshmallow_dataclass import class_schema
 
 from semantha_sdk.model.data_type import DataType
 from semantha_sdk.model.label import Label
 from semantha_sdk.model.metadata import Metadata
-from semantha_sdk.model.semantha_entity import SemanthaModelEntity
+from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
 
 
 @dataclass(frozen=True)
@@ -16,12 +17,14 @@ class Class(SemanthaModelEntity):
     name: str
     read_only: bool
     functional: bool
-    labels: list[Label]
-    metadata: list[Metadata]
+    labels: List[Label]
+    metadata: List[Metadata]
     comment: str
     datatype: DataType
-    attribute_ids: list[str]
+    attribute_ids: List[str]
     relevant_for_relation: bool
     object_property_id: str
     parent_id: str
 
+
+ClassSchema = class_schema(Class, base_schema=SemanthaSchema)
