@@ -1,8 +1,11 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from typing import List
 
-from semantha_sdk.model.semantha_entity import SemanthaModelEntity
+from marshmallow_dataclass import class_schema
+
+from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
 
 
 @dataclass(frozen=True)
@@ -11,6 +14,9 @@ class ClusteredDocument(SemanthaModelEntity):
     probability: float
 
 
+ClusteredDocumentSchema = class_schema(ClusteredDocument, base_schema=SemanthaSchema)
+
+
 @dataclass(frozen=True)
 class ClusteredParagraph(SemanthaModelEntity):
     document_id: str
@@ -18,12 +24,18 @@ class ClusteredParagraph(SemanthaModelEntity):
     probability: float
 
 
+ClusteredParagraphSchema = class_schema(ClusteredParagraph, base_schema=SemanthaSchema)
+
+
 @dataclass(frozen=True)
 class DocumentCluster(SemanthaModelEntity):
     id: int
     count: int
     label: str
-    content: list[ClusteredDocument]
+    content: List[ClusteredDocument]
+
+
+DocumentClusterSchema = class_schema(DocumentCluster, base_schema=SemanthaSchema)
 
 
 @dataclass(frozen=True)
@@ -31,14 +43,7 @@ class ParagraphCluster(SemanthaModelEntity):
     id: int
     count: int
     label: str
-    content: list[ClusteredParagraph]
+    content: List[ClusteredParagraph]
 
 
-@dataclass(frozen=True)
-class DocumentClusters(SemanthaModelEntity):
-    clusters: list[DocumentCluster]
-
-
-@dataclass(frozen=True)
-class ParagraphClusters(SemanthaModelEntity):
-    clusters: list[ParagraphCluster]
+ParagraphClusterSchema = class_schema(ParagraphCluster, base_schema=SemanthaSchema)
