@@ -1,7 +1,9 @@
 from dataclasses import dataclass
 
+from marshmallow_dataclass import class_schema
+
 from semantha_sdk.model.domain_settings import DomainSettings
-from semantha_sdk.model.semantha_entity import SemanthaModelEntity
+from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
 
 
 @dataclass(frozen=True)
@@ -11,3 +13,4 @@ class DomainConfiguration(SemanthaModelEntity):
     settings: DomainSettings
 
 
+DomainConfigurationSchema = class_schema(DomainConfiguration, base_schema=SemanthaSchema)
