@@ -27,11 +27,11 @@ ParagraphSchema = class_schema(Paragraph, base_schema=SemanthaSchema)
 
 @dataclass(frozen=True)
 class PatchParagraph(SemanthaModelEntity):
-    id: Optional[str]
-    type: Optional[str]
-    text: Optional[str]
-    sentences: Optional[List[Sentence]]
-    document_name: Optional[Optional[str]]
-    references: Optional[List[Reference]]
-    context: Optional[Dict[str, str]]
-    comment: Optional[str]
+    id: Optional[str] = None
+    type: Optional[str] = None
+    text: Optional[str] = None
+    sentences: Optional[List[Sentence]] = None
+    document_name: Optional[Optional[str]] = None
+    references: Optional[List[Reference]] = None
+    context: Optional[Dict[str, str]] = None
+    comment: Optional[str] = None
