@@ -12,7 +12,7 @@ from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSche
 class Reference(SemanthaModelEntity):
     document_id: str
     similarity: float
-    color: str
+    color: Optional[str]
     document_name: Optional[str]
     page_number: Optional[int]
     paragraph_id: Optional[str]
